client

Function client 

fn client() -> &'static Client<HttpConnector, Full<Bytes>>
One pooled client for the process. Alerts are rare and bursty, and a fresh TCP (and TLS) handshake per page is the whole latency of a page.