fn opt_float(y: &Yaml, what: &'static str) -> Result<Option<f64>, String>
optional double in the proto, so absent and 0 are different values and the difference is visible in a histogram.
optional double
0